@@ -4,12 +4,12 @@ function(name,
          inflow,
          Area,
          delayInflow,
-         label,
          downstream,
          transformMethod,
          lossMethod,
          BFSMethod,
          UH,
+         abstractionParams,
          transformParams,
          lossParams,
          BFSParams)
@@ -18,13 +18,14 @@ function(name,
                   precipitation=precipitation,
                   Area=Area,
                   delayInflow=delayInflow,
-                  label=label,
+                  label=runif(1),
                   downstream=downstream,
                   inflow=inflow,
                   transformMethod=transformMethod,
                   lossMethod=lossMethod,
                   BFSMethod=BFSMethod,
-                  HU=UH,
+                  UH=UH,
+                  abstractionParams=abstractionParams,
                   transformParams=transformParams,
                   lossParams=lossParams,
                   BFSParams=BFSParams)
